Modules
Structs
- AppInfo
- Application information.
- AppInfo
Report - Installed applications plus per-entry diagnostics.
- AppInfo
Warning - A non-fatal problem encountered during best-effort enumeration.
- Icon
- Shared RGBA icon data.
- List
Options - Controls how installed applications are enumerated.
Constants
- MAX_
ICON_ SIZE - Largest icon edge accepted by the library.
Functions
- find_
app_ by_ identifier - Finds an application by bundle identifier or Windows product code.
- find_
app_ by_ name - Finds the first application with the requested name.
- find_
apps_ by_ name - Finds all applications whose names match using Unicode lowercase mapping.
- get_
file_ icon - Gets the icon for a file path.
- get_
installed_ apps - Gets installed applications.
- get_
installed_ apps_ with_ options - Gets installed desktop applications using configurable behavior.